==> webpdf-wsclient-10.0.0-sources.jar: net/webpdf/wsclient/schema/operation/XRechnungType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p310440_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p351123_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;This element defines one "XRechnung" transformation and the resources and parameters necessary for it.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for XRechnungType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="XRechnungType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all>
 *         <element name="visualization" type="{http://schema.webpdf.de/1.0/operation}XRechnungResourcesType" minOccurs="0"/>
 *       </all>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "XRechnungType", propOrder = {

})
public class XRechnungType {

    protected XRechnungResourcesType visualization;

    /**
     * Gets the value of the visualization property.
     * 
     * @return
     *     possible object is
     *     {@link XRechnungResourcesType }
     *     
     */
    public XRechnungResourcesType getVisualization() {
        return visualization;
    }

    /**
     * Sets the value of the visualization property.
     * 
     * @param value
     *     allowed object is
     *     {@link XRechnungResourcesType }
     *     
     */
    public void setVisualization(XRechnungResourcesType value) {
        this.visualization = value;
    }

    public boolean isSetVisualization() {
        return (this.visualization!= null);
    }

}

==> webpdf-wsclient-10.0.1-sources.jar: net/webpdf/wsclient/schema/operation/XRechnungType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p165541_="https://jakarta.ee/xml/ns/jaxb" xmlns:p356920_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;This element defines one "XRechnung" transformation and the resources and parameters necessary for it.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for XRechnungType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="XRechnungType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all>
 *         <element name="visualization" type="{http://schema.webpdf.de/1.0/operation}XRechnungResourcesType" minOccurs="0"/>
 *       </all>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "XRechnungType", propOrder = {

})
public class XRechnungType {

    protected XRechnungResourcesType visualization;

    /**
     * Gets the value of the visualization property.
     * 
     * @return
     *     possible object is
     *     {@link XRechnungResourcesType }
     *     
     */
    public XRechnungResourcesType getVisualization() {
        return visualization;
    }

    /**
     * Sets the value of the visualization property.
     * 
     * @param value
     *     allowed object is
     *     {@link XRechnungResourcesType }
     *     
     */
    public void setVisualization(XRechnungResourcesType value) {
        this.visualization = value;
    }

    public boolean isSetVisualization() {
        return (this.visualization!= null);
    }

}
